# -*- coding: utf-8 -*-
import yaml
from pyramid.config import Configurator
from pyramid_mako import add_mako_renderer


__version__ = '1.2.5'


def main(global_config, **settings):  # pragma: no cover
    """
    This function returns a Pyramid WSGI application. This is necessary for development of
    your plugin. So you can run it local with the paster server and in a IDE like PyCharm. It
    is intended to leave this section as is and do configuration in the includeme section only.
    Push additional configuration in this section means it will not be used by the production
    environment at all!
    """
    with open('oereb_client.yml') as f:
        yml = yaml.safe_load(f.read())
    settings.update(yml)
    config = Configurator(settings=settings)
    config.include('oereb_client')
    config.include('samples')
    config.scan()
    return config.make_wsgi_app()


def includeme(config):  # pragma: no cover
    """
    This is the place where you should push all the initial stuff for the plugin
    :param config: The configurator object from the including pyramid module.
    :type geometries: Configurator
    """
    # If you need access to the settings in this part, you can get them via
    # settings = config.get_settings()
    global route_prefix

    config.include('pyramid_mako')

    # bind the mako renderer to other file extensions
    add_mako_renderer(config, ".html")
    add_mako_renderer(config, ".xml")
    add_mako_renderer(config, ".js")

    config.include('oereb_client.routes')

    def get_route_prefix(request):
        return config.route_prefix

    config.add_request_method(get_route_prefix, name='route_prefix', reify=True)



# -*- coding: utf-8 -*-
from oereb_client.views.wfs_query import WfsQuery
from views.deps import Depswriter
from views.index import Index


def includeme(config):  # pragma: no cover
    """Route and view definitions used by this application.

    Args:
        config (pyramid.config.Configurator): The application's configuration object.

    """

    # Static views
    config.add_static_view('static', 'oereb_client:static', cache_max_age=3600)
    config.add_static_view('node_modules', 'oereb_client:../node_modules', cache_max_age=3600)

    # index.html
    config.add_route('{0}/index'.format(config.route_prefix), '/')
    config.add_view(Index,
                    attr='render',
                    route_name='{0}/index'.format(config.route_prefix),
                    renderer='oereb_client:templates/index.html',
                    request_method='GET')

    # deps.js
    config.add_route('{0}/deps.js'.format(config.route_prefix), '/deps.js')
    config.add_view(Depswriter,
                    attr='render',
                    route_name='{0}/deps.js'.format(config.route_prefix),
                    request_method='GET')

    # wfs_query.xml
    config.add_route('{0}/wfs_filter'.format(config.route_prefix), '/wfs_filter.xml')
    config.add_view(WfsQuery,
                    attr='provide_wfs_filter',
                    route_name='{0}/wfs_filter'.format(config.route_prefix),
                    renderer='oereb_client:templates/wfs_filter.xml',
                    request_method='GET')

    config.commit()



# -*- coding: utf-8 -*-
import codecs
import os
import sys

from setuptools import setup, find_packages
from datetime import datetime

VERSION = '1.2.5'

test_mode = False
timestamp = datetime.now().strftime('%Y%m%d%H%M')

if "--test" in sys.argv:
    test_mode = True
    sys.argv.remove("--test")

here = os.path.abspath(os.path.dirname(__file__))
with codecs.open(os.path.join(here, 'README.rst'), encoding='utf-8') as f:
    README = f.read()
with codecs.open(os.path.join(here, 'CHANGELOG.rst'), encoding='utf-8') as f:
    CHANGES = f.read()

requires = [
    'pyramid',
    'pyramid_mako',
    'waitress'
]

setup(
    name='oereb_client',
    version=VERSION + '.dev{0}'.format(timestamp) if test_mode else VERSION,
    description='ÖREB Client',
    long_description=README + '\n\n' + CHANGES,
    classifiers=[
        "Development Status :: 4 - Beta" if test_mode else "Development Status :: 5 - Production/Stable",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.6",
        "Framework :: Pyramid",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Internet :: WWW/HTTP :: WSGI :: Application",
    ],
    author='Karsten Deininger',
    author_email='karsten.deininger@bl.ch',
    url='https://gitlab.com/gf-bl/oereb_client',
    keywords='web pyramid pylons oereb client angular openlayers',
    packages=find_packages(exclude=['samples', 'test*']),
    include_package_data=True,
    zip_safe=False,
    install_requires=requires,
    dependency_links=[],
    entry_points={
        'paste.app_factory': [
            'main = oereb_client:main'
        ]
    }
)
